Expand

Trait Expand 

pub trait Expand<T> {
    // Required method
    fn expand<I: IntoExpression<Item = T>>(&mut self, expr: I);
}
Trait for appending an expression to an array along the first dimension.

Required Methods

fn expand<I: IntoExpression<Item = T>>(&mut self, expr: I)

Expands an array with the contents of an expression along the first dimension.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T, U: IntoCloned<T>, S: Shape<Buffer<T, A> = DynBuffer<T, S, A>>, A: Allocator> Expand<U> for Array<T, S, A>