Module index

Module index 

Module for array slice and view indexing, and for array axis subarray types.

Structs

Cols
Column axis type, for the second last dimension.
Rows
Row axis type, for the last dimension.

Traits

Axis
Array axis trait, for subarray shapes.
DimIndex
Helper trait for array indexing, for a single index.
Permutation
Array permutation trait, for array types after permutation of dimensions.
SliceIndex
Array slice index trait, for an element or a subslice.
ViewIndex
Array view index trait, for a multidimensional index.