pub trait Expand<T> {
// Required method
fn expand<I: IntoExpression<Item = T>>(&mut self, expr: I);
}Expand description
Trait for appending an expression to an array along the first dimension.
Required Methods
Sourcefn expand<I: IntoExpression<Item = T>>(&mut self, expr: I)
fn expand<I: IntoExpression<Item = T>>(&mut self, expr: I)
Expands an array with the contents of an expression along the first dimension.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.