Module for array slice and view indexing, and for array axis subarray types.
Structs
Traits
- Axis
- Array axis trait, for subarray shapes.
- DimIndex
- Helper trait for array indexing, for a single index.
- Permutation
- Array permutation trait, for array types after permutation of dimensions.
- Slice
Index - Array slice index trait, for an element or a subslice.
- View
Index - Array view index trait, for a multidimensional index.