pub struct SpanBase<T, L: Copy> { /* private fields */ }Expand description
Multidimensional array span with static rank and element order.
Implementations
sourceimpl<T, L: Copy> SpanBase<T, L>
impl<T, L: Copy> SpanBase<T, L>
sourcepub fn as_mut_ptr(&mut self) -> *mut T
pub fn as_mut_ptr(&mut self) -> *mut T
Returns a mutable pointer to the array buffer.
sourcepub fn to_view_mut(&mut self) -> SubGridMut<'_, T, L>
pub fn to_view_mut(&mut self) -> SubGridMut<'_, T, L>
Returns a mutable array view of the entire array span.
sourceimpl<T, D: Dim, F: Format> SpanBase<T, Layout<D, F>>
impl<T, D: Dim, F: Format> SpanBase<T, Layout<D, F>>
sourcepub fn axis_iter<const DIM: usize>(
&self
) -> AxisIter<'_, T, Layout<D::Lower, <Const<DIM> as Axis<D>>::Remove<F>>>ⓘNotable traits for AxisIter<'a, T, L>impl<'a, T, L: Copy> Iterator for AxisIter<'a, T, L> type Item = SubGrid<'a, T, L>;where
Const<DIM>: Axis<D>,
pub fn axis_iter<const DIM: usize>(
&self
) -> AxisIter<'_, T, Layout<D::Lower, <Const<DIM> as Axis<D>>::Remove<F>>>ⓘNotable traits for AxisIter<'a, T, L>impl<'a, T, L: Copy> Iterator for AxisIter<'a, T, L> type Item = SubGrid<'a, T, L>;where
Const<DIM>: Axis<D>,
Returns an iterator that gives array views over the specified dimension.
When iterating over the outer dimension, both the unit inner stride and the uniform stride properties are maintained, and the resulting array views have the same format.
When iterating over the inner dimension, the uniform stride property is maintained but not unit inner stride, and the resulting array views have flat or strided format.
When iterating over the middle dimensions, the unit inner stride propery is maintained but not uniform stride, and the resulting array views have general or strided format.
sourcepub fn axis_iter_mut<const DIM: usize>(
&mut self
) -> AxisIterMut<'_, T, Layout<D::Lower, <Const<DIM> as Axis<D>>::Remove<F>>>ⓘNotable traits for AxisIterMut<'a, T, L>impl<'a, T, L: Copy> Iterator for AxisIterMut<'a, T, L> type Item = SubGridMut<'a, T, L>;where
Const<DIM>: Axis<D>,
pub fn axis_iter_mut<const DIM: usize>(
&mut self
) -> AxisIterMut<'_, T, Layout<D::Lower, <Const<DIM> as Axis<D>>::Remove<F>>>ⓘNotable traits for AxisIterMut<'a, T, L>impl<'a, T, L: Copy> Iterator for AxisIterMut<'a, T, L> type Item = SubGridMut<'a, T, L>;where
Const<DIM>: Axis<D>,
Returns a mutable iterator that gives array views over the specified dimension.
When iterating over the outer dimension, both the unit inner stride and the uniform stride properties are maintained, and the resulting array views have the same format.
When iterating over the inner dimension, the uniform stride property is maintained but not unit inner stride, and the resulting array views have flat or strided format.
When iterating over the middle dimensions, the unit inner stride propery is maintained but not uniform stride, and the resulting array views have general or strided format.
sourcepub fn fill(&mut self, value: impl Borrow<T>)where
T: Clone,
pub fn fill(&mut self, value: impl Borrow<T>)where
T: Clone,
Fills the array span with elements by cloning value.
sourcepub fn fill_with(&mut self, f: impl FnMut() -> T)
pub fn fill_with(&mut self, f: impl FnMut() -> T)
Fills the array span with elements returned by calling a closure repeatedly.
sourcepub fn flatten(&self) -> SubGrid<'_, T, Layout<Rank<1, D::Order>, F::Uniform>>
pub fn flatten(&self) -> SubGrid<'_, T, Layout<Rank<1, D::Order>, F::Uniform>>
Returns a one-dimensional array view of the array span.
Panics
Panics if the array layout is not uniformly strided.
sourcepub fn flatten_mut(
&mut self
) -> SubGridMut<'_, T, Layout<Rank<1, D::Order>, F::Uniform>>
pub fn flatten_mut(
&mut self
) -> SubGridMut<'_, T, Layout<Rank<1, D::Order>, F::Uniform>>
Returns a mutable one-dimensional array view over the array span.
Panics
Panics if the array layout is not uniformly strided.
sourcepub unsafe fn get_unchecked<I>(&self, index: I) -> &I::Outputwhere
I: SpanIndex<T, Layout<D, F>>,
pub unsafe fn get_unchecked<I>(&self, index: I) -> &I::Outputwhere
I: SpanIndex<T, Layout<D, F>>,
Returns a reference to an element or a subslice, without doing bounds checking.
Safety
The index must be within bounds of the array span.
sourcepub unsafe fn get_unchecked_mut<I>(&mut self, index: I) -> &mut I::Outputwhere
I: SpanIndex<T, Layout<D, F>>,
pub unsafe fn get_unchecked_mut<I>(&mut self, index: I) -> &mut I::Outputwhere
I: SpanIndex<T, Layout<D, F>>,
Returns a mutable reference to an element or a subslice, without doing bounds checking.
Safety
The index must be within bounds of the array span.
sourcepub fn grid<P: Params, I>(&self, index: I) -> DenseGrid<T, P::Dim>where
T: Clone,
I: ViewIndex<D, F, Params = P>,
pub fn grid<P: Params, I>(&self, index: I) -> DenseGrid<T, P::Dim>where
T: Clone,
I: ViewIndex<D, F, Params = P>,
sourcepub fn inner_iter(
&self
) -> AxisIter<'_, T, Layout<D::Lower, <D::Lower as Dim>::Format<F::NonUnitStrided>>>ⓘNotable traits for AxisIter<'a, T, L>impl<'a, T, L: Copy> Iterator for AxisIter<'a, T, L> type Item = SubGrid<'a, T, L>;
pub fn inner_iter(
&self
) -> AxisIter<'_, T, Layout<D::Lower, <D::Lower as Dim>::Format<F::NonUnitStrided>>>ⓘNotable traits for AxisIter<'a, T, L>impl<'a, T, L: Copy> Iterator for AxisIter<'a, T, L> type Item = SubGrid<'a, T, L>;
Returns an iterator that gives array views over the inner dimension.
Iterating over the inner dimension maintains the uniform stride property but not unit inner stride, so that the resulting array views have flat or strided format.
Panics
Panics if the rank is not at least 1.
sourcepub fn inner_iter_mut(
&mut self
) -> AxisIterMut<'_, T, Layout<D::Lower, <D::Lower as Dim>::Format<F::NonUnitStrided>>>ⓘNotable traits for AxisIterMut<'a, T, L>impl<'a, T, L: Copy> Iterator for AxisIterMut<'a, T, L> type Item = SubGridMut<'a, T, L>;
pub fn inner_iter_mut(
&mut self
) -> AxisIterMut<'_, T, Layout<D::Lower, <D::Lower as Dim>::Format<F::NonUnitStrided>>>ⓘNotable traits for AxisIterMut<'a, T, L>impl<'a, T, L: Copy> Iterator for AxisIterMut<'a, T, L> type Item = SubGridMut<'a, T, L>;
Returns a mutable iterator that gives array views over the inner dimension.
Iterating over the inner dimension maintains the uniform stride property but not unit inner stride, so that the resulting array views have flat or strided format.
Panics
Panics if the rank is not at least 1.
sourcepub fn is_contiguous(&self) -> bool
pub fn is_contiguous(&self) -> bool
Returns true if the array strides are consistent with contiguous memory layout.
sourcepub fn is_uniformly_strided(&self) -> bool
pub fn is_uniformly_strided(&self) -> bool
Returns true if the array strides are consistent with uniformly strided memory layout.
sourcepub fn iter(&self) -> F::Iter<'_, T>where
F: Uniform,
pub fn iter(&self) -> F::Iter<'_, T>where
F: Uniform,
Returns an iterator over the array span, which must support linear indexing.
sourcepub fn iter_mut(&mut self) -> F::IterMut<'_, T>where
F: Uniform,
pub fn iter_mut(&mut self) -> F::IterMut<'_, T>where
F: Uniform,
Returns a mutable iterator over the array span, which must support linear indexing.
sourcepub fn outer_iter(
&self
) -> AxisIter<'_, T, Layout<D::Lower, <D::Lower as Dim>::Format<F>>>ⓘNotable traits for AxisIter<'a, T, L>impl<'a, T, L: Copy> Iterator for AxisIter<'a, T, L> type Item = SubGrid<'a, T, L>;
pub fn outer_iter(
&self
) -> AxisIter<'_, T, Layout<D::Lower, <D::Lower as Dim>::Format<F>>>ⓘNotable traits for AxisIter<'a, T, L>impl<'a, T, L: Copy> Iterator for AxisIter<'a, T, L> type Item = SubGrid<'a, T, L>;
Returns an iterator that gives array views over the outer dimension.
Iterating over the outer dimension maintains both the unit inner stride and the uniform stride properties, and the resulting array views have the same format.
Panics
Panics if the rank is not at least 1.
sourcepub fn outer_iter_mut(
&mut self
) -> AxisIterMut<'_, T, Layout<D::Lower, <D::Lower as Dim>::Format<F>>>ⓘNotable traits for AxisIterMut<'a, T, L>impl<'a, T, L: Copy> Iterator for AxisIterMut<'a, T, L> type Item = SubGridMut<'a, T, L>;
pub fn outer_iter_mut(
&mut self
) -> AxisIterMut<'_, T, Layout<D::Lower, <D::Lower as Dim>::Format<F>>>ⓘNotable traits for AxisIterMut<'a, T, L>impl<'a, T, L: Copy> Iterator for AxisIterMut<'a, T, L> type Item = SubGridMut<'a, T, L>;
Returns a mutable iterator that gives array views over the outer dimension.
Iterating over the outer dimension maintains both the unit inner stride and the uniform stride properties, and the resulting array views have the same format.
Panics
Panics if the rank is not at least 1.
sourcepub fn reformat<G: Format>(&self) -> SubGrid<'_, T, Layout<D, G>>
pub fn reformat<G: Format>(&self) -> SubGrid<'_, T, Layout<D, G>>
Returns a reformatted array view of the array span.
Panics
Panics if the array layout is not compatible with the new format.
sourcepub fn reformat_mut<G: Format>(&mut self) -> SubGridMut<'_, T, Layout<D, G>>
pub fn reformat_mut<G: Format>(&mut self) -> SubGridMut<'_, T, Layout<D, G>>
Returns a mutable reformatted array view of the array span.
Panics
Panics if the array layout is not compatible with the new format.
sourcepub fn reshape<S: Shape>(
&self,
shape: S
) -> SubGrid<'_, T, Layout<S::Dim<D::Order>, <S::Dim<D::Order> as Dim>::Format<F>>>
pub fn reshape<S: Shape>(
&self,
shape: S
) -> SubGrid<'_, T, Layout<S::Dim<D::Order>, <S::Dim<D::Order> as Dim>::Format<F>>>
Returns a reshaped array view of the array span, with similar layout.
Panics
Panics if the array length is changed, or the memory layout is not compatible.
sourcepub fn reshape_mut<S: Shape>(
&mut self,
shape: S
) -> SubGridMut<'_, T, Layout<S::Dim<D::Order>, <S::Dim<D::Order> as Dim>::Format<F>>>
pub fn reshape_mut<S: Shape>(
&mut self,
shape: S
) -> SubGridMut<'_, T, Layout<S::Dim<D::Order>, <S::Dim<D::Order> as Dim>::Format<F>>>
Returns a mutable reshaped array view of the array span, with similar layout.
Panics
Panics if the array length is changed, or the memory layout is not compatible.
sourcepub fn size(&self, dim: usize) -> usize
pub fn size(&self, dim: usize) -> usize
Returns the number of elements in the specified dimension.
sourcepub fn split_at(
&self,
mid: usize
) -> (SubGrid<'_, T, Layout<D, F>>, SubGrid<'_, T, Layout<D, F>>)
pub fn split_at(
&self,
mid: usize
) -> (SubGrid<'_, T, Layout<D, F>>, SubGrid<'_, T, Layout<D, F>>)
Divides an array span into two at an index along the outer dimension.
Panics
Panics if the split point is larger than the number of elements in that dimension.
sourcepub fn split_at_mut(
&mut self,
mid: usize
) -> (SubGridMut<'_, T, Layout<D, F>>, SubGridMut<'_, T, Layout<D, F>>)
pub fn split_at_mut(
&mut self,
mid: usize
) -> (SubGridMut<'_, T, Layout<D, F>>, SubGridMut<'_, T, Layout<D, F>>)
Divides a mutable array span into two at an index along the outer dimension.
Panics
Panics if the split point is larger than the number of elements in that dimension.
sourcepub fn split_axis_at<const DIM: usize>(
&self,
mid: usize
) -> (SubGrid<'_, T, Layout<D, <Const<DIM> as Axis<D>>::Split<F>>>, SubGrid<'_, T, Layout<D, <Const<DIM> as Axis<D>>::Split<F>>>)where
Const<DIM>: Axis<D>,
pub fn split_axis_at<const DIM: usize>(
&self,
mid: usize
) -> (SubGrid<'_, T, Layout<D, <Const<DIM> as Axis<D>>::Split<F>>>, SubGrid<'_, T, Layout<D, <Const<DIM> as Axis<D>>::Split<F>>>)where
Const<DIM>: Axis<D>,
Divides an array span into two at an index along the specified dimension.
Panics
Panics if the split point is larger than the number of elements in that dimension.
sourcepub fn split_axis_at_mut<const DIM: usize>(
&mut self,
mid: usize
) -> (SubGridMut<'_, T, Layout<D, <Const<DIM> as Axis<D>>::Split<F>>>, SubGridMut<'_, T, Layout<D, <Const<DIM> as Axis<D>>::Split<F>>>)where
Const<DIM>: Axis<D>,
pub fn split_axis_at_mut<const DIM: usize>(
&mut self,
mid: usize
) -> (SubGridMut<'_, T, Layout<D, <Const<DIM> as Axis<D>>::Split<F>>>, SubGridMut<'_, T, Layout<D, <Const<DIM> as Axis<D>>::Split<F>>>)where
Const<DIM>: Axis<D>,
Divides a mutable array span into two at an index along the specified dimension.
Panics
Panics if the split point is larger than the number of elements in that dimension.
sourcepub fn stride(&self, dim: usize) -> isize
pub fn stride(&self, dim: usize) -> isize
Returns the distance between elements in the specified dimension.
sourcepub fn to_grid(&self) -> DenseGrid<T, D>where
T: Clone,
pub fn to_grid(&self) -> DenseGrid<T, D>where
T: Clone,
Copies the array span into a new array.
sourcepub fn to_vec(&self) -> Vec<T>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,where
T: Clone,
pub fn to_vec(&self) -> Vec<T>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,where
T: Clone,
A: Allocator,
Copies the array span into a new vector.